pub struct ManifestDiff {
pub added: Vec<ManifestEntry>,
pub removed: Vec<ManifestEntry>,
}Expand description
The result of comparing two ContentManifest instances.
Comparison is done by CID: an entry present in new but absent in old
(by CID) is added; an entry present in old but absent in new is
removed.
Fields
added: Vec<ManifestEntry>Entries that exist in the new manifest but not the old one.
removed: Vec<ManifestEntry>Entries that exist in the old manifest but not the new one.
Implementations
Sourceimpl ManifestDiff
impl ManifestDiff
Sourcepub fn diff(old: &ContentManifest, new: &ContentManifest) -> Self
pub fn diff(old: &ContentManifest, new: &ContentManifest) -> Self
Compute the diff between old and new manifests.